import setuptools

setuptools.setup(
    name="iehf",                     # This is the name of the package
    version="0.0.13",                        # The initial release version
    author="Ronkochu",                     # Full name of the author
    description="HF for IE",
    long_description="",      # Long description read from the the readme file
    long_description_content_type="text/markdown",
    # List of all python modules to be installed
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],                                      # Information to filter the project on PyPi website
    python_requires='>=3.6',                # Minimum version requirement of the package
    py_modules=["iehf"],             # Name of the python package
    # Directory of the source code of the package
    package_dir={'': 'iehf/src'},
    install_requires=[
        'numpy',
        'inflect',
        'scipy'
    ]                     # Install other dependencies if any
)
